
package com.tangosol.examples.data;


import com.tangosol.run.xml.XmlBean;

import com.tangosol.util.ListMap;

import java.util.Random;
import java.util.Map;
import java.util.Iterator;


/**
 * Example Trade domain object
 * Implements the XMLBean interface for quick serialization.
 *
 * @author erm 2005.12.27
 */
public class Trade extends XmlBean {
    // ----- constructors ---------------------------------------------------

    public Trade() {
    }

    public Trade(int iId, double dPrice, String sSymbol, int nShares, long orderTime) {
        setId(iId);
        setPrice(dPrice);
        setSymbol(sSymbol);
        setLot(nShares);
        setOrderTime(orderTime);
    }

    // ----- properties -----------------------------------------------------

    public int getId() {
        return m_iId;
    }

    public void setId(int iId) {
        m_iId = iId;
    }

    public String getSymbol() {
        return m_sSymbol;
    }

    public void setSymbol(String sSymbol) {
        m_sSymbol = sSymbol;
    }

    public double getPrice() {
        return m_dPrice;
    }

    public void setPrice(double dPrice) {
        m_dPrice = dPrice;
    }

    public int getLot() {
        return m_nLot;
    }

    public void setLot(int nLot) {
        m_nLot = nLot;
    }
    
    public void setOrderTime(long timeInMillis) {
        this.orderTime = timeInMillis;
    }
    
    public long getOrderTime() {
        return this.orderTime;
    }


    // ----- calculated properties -----------------------------------------

    public boolean isOddLot() {
        return getLot() < 10;
    }


    // ----- unit test -----------------------------------------------------

    public static void main(String[] asArg) {
        Map map = new ListMap();
        fillRandom(map, asArg.length == 0 ? 1 : Integer.parseInt(asArg[0]));
        for (Iterator iter = map.values().iterator(); iter.hasNext(); ) {
            out(iter.next());
        }
    }


    // ----- data members ---------------------------------------------------

    private int m_iId;
    private String m_sSymbol;
    private double m_dPrice;
    private int m_nLot; // number of shares
    private long orderTime;


    // ----- testing helpers ------------------------------------------------

    /**
     * Fill the specified Map with random data.
     */
    public static void fillRandom(Map map, int cnt) {
        final Random RND = getRandom();

        // generate test data;
        // for every 16 entries there will be one parent with one child
        // and one parent with two children
        for (int i = 0; i < cnt; ++i) {
            map.put(makeInteger(i), makeRandomTrade(i));
        }
    }

    /**
     * Make a Trade object for the specified Id with random data.
     *
     * @param iId  the Trade ID
     * @return a new Trade object
     */
    public static Trade makeRandomTrade(int iId) {
        final Random RND = getRandom();
        String sSymbol = SYMBOL[RND.nextInt(SYMBOL.length)];
        double dPrice = (new Double(RND.nextInt(10))).doubleValue();
        int nShares = RND.nextInt(100);

        return new Trade(iId, dPrice, sSymbol, nShares, System.currentTimeMillis());
    }

    public static final String[] SYMBOL = 
        parseDelimitedString("SUNW,MSFT,ORCL,GOOG", ',');
}
