
package com.tangosol.examples.trading;

import com.tangosol.net.cache.AbstractCacheStore;
import com.tangosol.util.SafeHashMap;
import com.tangosol.examples.data.Trade;

import java.util.Map;


/**
 * Dummy implementation of a CacheStore for the Trade objects.
 * This implementation will materialize requested objects using random data.
 *
 * @author mf 2006.05.02
 */
public class DummyTradingCacheStore extends AbstractCacheStore {

    /**
     * Construct the dummy store.
     */
    public DummyTradingCacheStore() {
        m_mapStorage = new SafeHashMap();
    }

    /**
     * Store the key value pair into the cache
     * @param oKey
     * @param oValue
     */
    public void store(Object oKey, Object oValue) {
        m_mapStorage.put(oKey, oValue);
    }

    /**
     * Remove a a value from the cache
     * @param oKey which corresponds to the value to remove
     */
    public void erase(Object oKey) {
        m_mapStorage.remove(oKey);
    }

    /**
     * Loads a random trade into the cache.
     * @param oKey
     * @return a Randomized trade
     */
    public Object load(Object oKey) {
        Map mapStorage = m_mapStorage;

        Object oValue = mapStorage.get(oKey);
        if (oValue == null) {
            synchronized (mapStorage) {
                if (mapStorage.containsKey(oKey)) {
                    oValue = mapStorage.get(oKey);
                } else {
                    // create a random Trade object for this key
                    oValue = Trade.makeRandomTrade(((Integer)oKey).intValue());
                    mapStorage.put(oKey, oValue);
                }
            }
        }
        return oValue;
    }


    // ---- data members ----------------------------------------------------

    /**
     * The storage for the dummy trades.
     */
    protected Map m_mapStorage;
}
