package com.tangosol.examples.trading;


import com.tangosol.util.Base;
import com.tangosol.util.extractor.ReflectionExtractor;
import com.tangosol.net.NamedCache;
import com.tangosol.net.CacheFactory;

import java.util.List;
import java.util.ArrayList;


/**
 * Loads a 1,000,000 random trades into the cache and indexes the symbol and price
 * data.
 *
 * @author erm 2006.
 */
public class TradeLoader extends Base {
    private static final int NUM_OF_TRADES = 100000;

    public static void main(String[] asArgs) {
        //how many trades do we want to load?
        long lTime = new TradeLoader().loadTrades(NUM_OF_TRADES);
        out("Load Time: " + lTime + " ms");
    }
    
    /**
     * Load some trades and index them
     * @param number trades to load
     * @return time in milliseconds to perform the load
     */
    public long loadTrades(int iCount) {
        NamedCache cache = CacheFactory.getCache("demo");

        out("<Adding Indexes>");
        //index tradeRef.getSymbol()
        cache.addIndex(new ReflectionExtractor("getSymbol"), true, null);
        //index tradeRef.getPrice()
        cache.addIndex(new ReflectionExtractor("getPrice"), true, null);
        cache.addIndex(new ReflectionExtractor("getLot"), true, null);
        List list = new ArrayList();
        //fills a list with a bunch ints
        for (int i = 0; i < iCount; ++i) {
            list.add(new Integer(i));
        }

        long lStart = System.currentTimeMillis();
        /*
         * find all the keys that match this will cause Cache load to create 
         * a random trade for each item in the list.
         */
        cache.getAll(list);

        return System.currentTimeMillis() - lStart;
    }
}
