package com.tangosol.examples.trading;

import com.tangosol.examples.data.Trade;

import com.tangosol.net.CacheFactory;
import com.tangosol.net.NamedCache;
import com.tangosol.net.cache.ContinuousQueryCache;

import com.tangosol.util.Filter;

import com.tangosol.util.filter.AndFilter;

import com.tangosol.util.filter.EqualsFilter;

import com.tangosol.util.filter.GreaterFilter;

import java.io.Serializable;

import java.util.Collection;
import java.util.List;

import java.util.Set;

import javax.servlet.http.HttpSessionBindingEvent;
import javax.servlet.http.HttpSessionEvent;
import javax.servlet.http.HttpSessionListener;

public class TradeSymbolRepository implements HttpSessionListener,Serializable {
    private ContinuousQueryCache query = null;
    private String symbol;
    
    /**
     * Construct a repository for a given symbol
     * @param symbol you want a repository for
     */
    public TradeSymbolRepository(String symbol) {
        this.symbol = symbol;        
    }
    
    /**
     * Find all the high end trades
     * @return a collection of trades
     */
    public synchronized Collection<Trade> getAllBigTrades() {
        //make sure the cluster is up
        CacheFactory.ensureCluster();
        //grab the cache
        NamedCache cache = CacheFactory.getCache("demo");
            //make sure no one else did this stuff if we were blocked
             if (query == null) {
             //find all trades for the symbol that has more than 900 lots and
             //price greater higher than $9
                Filter filter = new AndFilter(new EqualsFilter("getSymbol",symbol), new AndFilter(new GreaterFilter("getLot",900), new GreaterFilter("getPrice",9.0)));
                query = new ContinuousQueryCache(cache, filter, false);
             }
        return (Collection <Trade>)query.values();
    }


    public void sessionCreated(HttpSessionEvent httpSessionEvent) {
    }
    
    /**
     * Release the query when the session is now longer valid
     * @param httpSessionEvent
     */
    public synchronized void  sessionDestroyed(HttpSessionEvent httpSessionEvent) {
        if (query != null) {
                //clean up the resources for the continuous query
                query.release();
        }
    }
}
